<?php
/**
 * Icon Arena functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Icon_Arena
 */

if ( ! function_exists( 'icon_arena_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function icon_arena_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Icon Arena, use a find and replace
		 * to change 'icon-arena' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'icon-arena', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'icon-arena' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'icon_arena_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'icon_arena_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */


//add menu

add_theme_support('menus'); 

register_sidebar(array(

        'name' => __( 'Menu widget', 'icon-arena' ),

        'id' => 'menuwidget',

        'description' => __( 'Widgets in this area will be shown on menu.', 'icon-arena' ),

        'before_title' => '<h4 class="sidebar-title">',

        'after_title' => '</h4>',
        
        'before_widget' => '<div class="widget-item">',

        'after_widget' => '</div><!-- widget end -->',

    ) );
register_sidebar(array(

        'name' => __( 'Footer Area 1', 'icon-arena' ),

        'id' => 'footer1',

        'description' => __( 'Widgets in this area will be shown on footer1.', 'icon-arena' ),

        'before_title' => '<h4 class="sidebar-title">',

        'after_title' => '</h4>',
        
        'before_widget' => '<div class="widget-item">',

        'after_widget' => '</div><!-- widget end -->',

    ) );
register_sidebar(array(

        'name' => __( 'Footer Area 2', 'icon-arena' ),

        'id' => 'footer2',

        'description' => __( 'Widgets in this area will be shown on footer2.', 'icon-arena' ),

        'before_title' => '<h4 class="sidebar-title">',

        'after_title' => '</h4>',
        
        'before_widget' => '<div class="widget-item">',

        'after_widget' => '</div><!-- widget end -->',
    ) );
register_sidebar(array(

        'name' => __( 'Footer Area 3', 'icon-arena' ),

        'id' => 'footer3',

        'description' => __( 'Widgets in this area will be shown on footer3.' , 'icon-arena'),

        'before_title' => '<h4 class="sidebar-title">',

        'after_title' => '</h4>',
        
        'before_widget' => '<div class="widget-item">',

        'after_widget' => '</div><!-- widget end -->',
    ) );
register_sidebar(array(

        'name' => __( 'Footer Area 4', 'icon-arena' ),

        'id' => 'footer4',

        'description' => __( 'Widgets in this area will be shown on footer4.', 'icon-arena' ),

        'before_title' => '<h4 class="sidebar-title">',

        'after_title' => '</h4>',
        
        'before_widget' => '<div class="widget-item">',

        'after_widget' => '</div><!-- widget end -->',
    ) ); 




function icon_arena_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'icon_arena_content_width', 640 );
}
add_action( 'after_setup_theme', 'icon_arena_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function icon_arena_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'icon-arena' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'icon-arena' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'icon_arena_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function icon_arena_scripts() {
	
	wp_enqueue_style( 'icon-arena-style', get_stylesheet_uri() );
	wp_enqueue_style('font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css');
	wp_enqueue_style('bootstrap', get_template_directory_uri() . '/css/bootstrap.css');	

	wp_enqueue_script('icon-arena-script', get_template_directory_uri() . '/js/bootstrap.js', array(), '1.0.0', true);
	wp_enqueue_script('jquery');
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'icon_arena_scripts' );


/**
 * Replaces "[...]" (appended to automatically generated excerpts) with ... and
 * a 'Continue reading' link.
 *
 * @since Clickright 1.0
 *
 * @param string $link Link to single post/page.
 * @return &hellip.
 */
function icon_arena_excerpt_more( $link ) {
	if ( is_admin() ) {
		return $link;
	}

	$link = sprintf( '<p class="link-more"><a href="%1$s" class="more-link">%2$s</a></p>',
		esc_url( get_permalink( get_the_ID() ) ),
		/* translators: %s: Name of current post */
		sprintf( __( 'Continue reading<span class="screen-reader-text"> "%s"</span>', 'icon-arena' ), get_the_title( get_the_ID() ) )
	);
	return ' &hellip; ' ;
}
add_filter( 'excerpt_more', 'icon_arena_excerpt_more' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Load WooCommerce compatibility file.
 */
if ( class_exists( 'WooCommerce' ) ) {
	require get_template_directory() . '/inc/woocommerce.php';
}
